CREATE TABLE ASSISTANT_CONFIG (
    ID        		  NUMBER 	      NOT NULL,
    NOME              VARCHAR2(500)   NOT NULL,
    DESCRICAO 		  VARCHAR2(500)   NOT NULL,
    TIPO      		  VARCHAR2(1) 	  NOT NULL,
    ORDEM     		  NUMBER	      DEFAULT 1 NOT NULL,
    INTERVALO 		  NUMBER 		  NOT NULL,
    ATIVO     		  VARCHAR2(1) 	  DEFAULT 'S' NOT NULL,
    NRORG             NUMBER 	      DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg') 		NOT NULL,
    IDATIVO           VARCHAR2(1)     DEFAULT 'S'					NOT NULL,
    DTINCLUSAO        DATE            DEFAULT SYSDATE,
    DTULTATU          DATE            DEFAULT SYSDATE,
    NRORGINCLUSAO     NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERINCLUSAO    VARCHAR2(12)    DEFAULT '1' 					NULL,
    NRORGULTATU       NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERULTATU      VARCHAR2(12)    DEFAULT '1',
		CONSTRAINT PK_ASSISTANT_CONFIG PRIMARY KEY (ID),
		CONSTRAINT CKC_IDATIVO_ASSISTANT_CONFIG CHECK (IDATIVO IN ('S','N'))
)
/
CREATE SEQUENCE SEQ_ASSISTANT_CONFIG START WITH 1 MINVALUE 1 INCREMENT BY 1
/
CREATE OR REPLACE TRIGGER GERA_ID_ASSISTANT_CONFIG
BEFORE INSERT ON ASSISTANT_CONFIG FOR EACH ROW
BEGIN
  SELECT SEQ_ASSISTANT_CONFIG.NEXTVAL
    INTO :NEW.ID
    FROM DUAL;
END;
/
INSERT INTO ASSISTANT_CONFIG (NOME, DESCRICAO, TIPO, ORDEM, ATIVO, COMANDO, INTERVALO)
                      VALUES ('SAT', 'Monitoramento do SAT', 'I', 1, 'S', 'INTERNO', 60)
/
INSERT INTO ASSISTANT_CONFIG (NOME, DESCRICAO, TIPO, ORDEM, ATIVO, COMANDO, INTERVALO)
                      VALUES ('Servios Updater', 'Monitoramento de Servios do Updater', 'I', 1, 'S', 'INTERNO', 60)
/
CREATE TABLE UPDATEREVENTOS
(
	CDFILIAL          VARCHAR2(4),
	CDEVENTO	      VARCHAR2(16),
	CDUUID		      VARCHAR2(36),
	CDPRODUCTID	      VARCHAR2(16),
	CDPRODFILIID	  VARCHAR2(16),
	IDSTEVENTO        VARCHAR2(32) 	  NOT NULL,
	NRVERSAOATUAL	  VARCHAR2(12),
	NRVERSAOALVO	  VARCHAR2(12),
	IDCRIARVERSAO     VARCHAR2(1) 	  DEFAULT 'N' NOT NULL ,          
	NRORG             NUMBER 	      DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg') 		NOT NULL,
    IDATIVO           VARCHAR2(1)     DEFAULT 'S'					NOT NULL,
    DTINCLUSAO        DATE            DEFAULT SYSDATE,
    DTULTATU          DATE            DEFAULT SYSDATE,
    NRORGINCLUSAO     NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERINCLUSAO    VARCHAR2(12)    DEFAULT '1' 					NULL,
    NRORGULTATU       NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERULTATU      VARCHAR2(12)    DEFAULT '1',
		CONSTRAINT PK_UPDATEREVENTOS PRIMARY KEY (CDEVENTO),
		CONSTRAINT CKC_IDATIVO_UPDATEREVENTOS CHECK (IDATIVO IN ('S','N')),
		CONSTRAINT CKC_IDCRIAVER_UPDATEREVENTOS CHECK (IDCRIARVERSAO IN ('S', 'N')),
		CONSTRAINT CKC_IDSTEVENTO_UPDATEREVENTOS CHECK (IDSTEVENTO IN ('INSTALACAO_PENDENTE', 'INSTALACAO_EM_CURSO', 'REMOCAO_PENDENTE', 'REMOCAO_EM_CURSO', 'FINALIZADO', 'CANCELADO'))
)
/
CREATE TABLE UPDATERHISTORICO
(
	CDFILIAL          VARCHAR2(4),
	CDHISTORICO       VARCHAR2(16),
	CDEVENTO	      VARCHAR2(16),
	CDOPERADOR        VARCHAR2(12),
	CDUUID		      VARCHAR2(36),
	CDPRODUCTID	      VARCHAR2(16),
	NMPRODUCT 	      VARCHAR2(16),
	IDSTEVENTO        VARCHAR2(32) 	  NOT NULL,
	NRVERSAOATUAL	  VARCHAR2(12),
	NRVERSAOALVO	  VARCHAR2(12),
	IDCRIARVERSAO     VARCHAR2(1) 	  DEFAULT 'N' NOT NULL,
	NRORG             NUMBER 	      DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg') 		NOT NULL,
    IDATIVO           VARCHAR2(1)     DEFAULT 'S'					NOT NULL,
    DTINCLUSAO        DATE            DEFAULT SYSDATE,
    DTULTATU          DATE            DEFAULT SYSDATE,
    NRORGINCLUSAO     NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERINCLUSAO    VARCHAR2(12)    DEFAULT '1' 					NULL,
    NRORGULTATU       NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERULTATU      VARCHAR2(12)    DEFAULT '1',
		CONSTRAINT PK_UPDATERHISTORICO PRIMARY KEY (CDHISTORICO),
		CONSTRAINT CKC_IDSTEVENTO_UPDHIST CHECK (IDSTEVENTO IN ('INSTALACAO_PENDENTE', 'INSTALACAO_EM_CURSO', 'REMOCAO_PENDENTE', 'REMOCAO_EM_CURSO', 'FINALIZADO', 'CANCELADO')),
		CONSTRAINT CKC_IDATIVO_UPDATERHISTORICO CHECK (IDATIVO IN ('S','N'))
)
/
CREATE TABLE UPDATERPRODUTOS
(
	ID                NUMBER          NOT NULL,
    NMPRODUCT 	      VARCHAR2(100)   NOT NULL,
	IDUTMULTVER       VARCHAR2(1)     DEFAULT 'N' NOT NULL,
	NRORG             NUMBER 	      DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg') 		NOT NULL,
    IDATIVO           VARCHAR2(1)     DEFAULT 'S'					NOT NULL,
    DTINCLUSAO        DATE            DEFAULT SYSDATE,
    DTULTATU          DATE            DEFAULT SYSDATE,
    NRORGINCLUSAO     NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERINCLUSAO    VARCHAR2(12)    DEFAULT '1' 					NULL,
    NRORGULTATU       NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERULTATU      VARCHAR2(12)    DEFAULT '1',
		CONSTRAINT CKC_IDATIVO_UPDATERPRODUTOS CHECK (IDATIVO IN ('S','N')),
		CONSTRAINT CKC_IDUTMULTVER_UPDPROD CHECK (IDUTMULTVER IN ('S', 'N')),
		CONSTRAINT PK_UPDATERPRODUTOS PRIMARY KEY (ID)
)
/
CREATE TABLE UPDATERPRODVERSAO
(
	ID                NUMBER          NOT NULL,
	UPDATERPRODID     NUMBER          NOT NULL,
	NRVERSAO          VARCHAR2(10)    NOT NULL,
	DSURL      	      VARCHAR2(100)   NOT NULL,
	DSDIRETORIO	      VARCHAR2(100),
	IDDOWNLOADVER     VARCHAR2(1)	  DEFAULT 'P' NOT NULL,
    IDAPROVVER     	  VARCHAR2(1)	  DEFAULT 'N' NOT NULL,
	NRORG             NUMBER 	      DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg') 		NOT NULL,
    IDATIVO           VARCHAR2(1)     DEFAULT 'S'					NOT NULL,
    DTINCLUSAO        DATE            DEFAULT SYSDATE,
    DTULTATU          DATE            DEFAULT SYSDATE,
    NRORGINCLUSAO     NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERINCLUSAO    VARCHAR2(12)    DEFAULT '1' 					NULL,
    NRORGULTATU       NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERULTATU      VARCHAR2(12)    DEFAULT '1',
		CONSTRAINT CKC_IDATIVO_UPDATERPRODVERSAO CHECK (IDATIVO IN ('S','N')),
		CONSTRAINT PK_UPDATERPRODVERSAO  PRIMARY KEY (ID),
		CONSTRAINT FKVND00844UPDATERPRODVERPROD FOREIGN KEY (UPDATERPRODID) REFERENCES UPDATERPRODUTOS (ID)
)
/
CREATE INDEX VND00844_FK ON UPDATERPRODVERSAO  (UPDATERPRODID)
/
CREATE SEQUENCE SEQ_UPDATERPRODVERSAO START WITH 1 MINVALUE 1 INCREMENT BY 1
/
CREATE OR REPLACE TRIGGER GERA_ID_UPDATERPRODVERSAO
BEFORE INSERT ON UPDATERPRODVERSAO FOR EACH ROW
BEGIN
  SELECT SEQ_UPDATERPRODVERSAO.NEXTVAL
    INTO :NEW.ID
    FROM DUAL;
END;
/
CREATE TABLE UPDATERPRODFILI
(
	ID                NUMBER          NOT NULL,
	UPDATERPRODID     NUMBER          NOT NULL,
	CDFILIAL          VARCHAR2(4)     NOT NULL,
	NRVERSAOATUAL	  VARCHAR2(10),
	NRORG             NUMBER 	      DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg') 		NOT NULL,
    IDATIVO           VARCHAR2(1)     DEFAULT 'S'					NOT NULL,
    DTINCLUSAO        DATE            DEFAULT SYSDATE,
    DTULTATU          DATE            DEFAULT SYSDATE,
    NRORGINCLUSAO     NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERINCLUSAO    VARCHAR2(12)    DEFAULT '1' 					NULL,
    NRORGULTATU       NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERULTATU      VARCHAR2(12)    DEFAULT '1',
		CONSTRAINT CKC_IDATIVO_UPDATERPRODFILI CHECK (IDATIVO IN ('S','N')),
		CONSTRAINT PK_UPDATERPRODFILI PRIMARY KEY (ID),
		CONSTRAINT FKVND00845UPDATERPRODFILIPROD FOREIGN KEY (UPDATERPRODID) REFERENCES UPDATERPRODUTOS (ID)
)
/
CREATE INDEX VND00845_FK ON UPDATERPRODFILI  (UPDATERPRODID)
/
CREATE SEQUENCE SEQ_UPDATERPRODFILI START WITH 1 MINVALUE 1 INCREMENT BY 1
/
CREATE OR REPLACE TRIGGER GERA_ID_UPDATERPRODFILI
BEFORE INSERT ON UPDATERPRODFILI FOR EACH ROW
BEGIN
  SELECT SEQ_UPDATERPRODFILI.NEXTVAL
    INTO :NEW.ID
    FROM DUAL;
END;
/
CREATE TABLE UPDATERCONFIG
(
    ID                NUMBER          NOT NULL,
    CDFILIAL          VARCHAR2(4)     NOT NULL,
    CONFIG            VARCHAR2(4000)  NOT NULL,
	NRORG             NUMBER 	      DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg') 		NOT NULL,
    IDATIVO           VARCHAR2(1)     DEFAULT 'S'					NOT NULL,
    DTINCLUSAO        DATE            DEFAULT SYSDATE,
    DTULTATU          DATE            DEFAULT SYSDATE,
    NRORGINCLUSAO     NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERINCLUSAO    VARCHAR2(12)    DEFAULT '1' 					NULL,
    NRORGULTATU       NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERULTATU      VARCHAR2(12)    DEFAULT '1',
		CONSTRAINT CKC_IDATIVO_UPDATERCONFIG CHECK (IDATIVO IN ('S','N')),
		CONSTRAINT PK_UPDATERCONFIG PRIMARY KEY (ID),
		CONSTRAINT FKVND00846UPDATERCONFIGFILIAL FOREIGN KEY (CDFILIAL) REFERENCES FILIAL (CDFILIAL)
)
/
CREATE INDEX VND00846_FK ON UPDATERCONFIG  (CDFILIAL)
/
CREATE SEQUENCE SEQ_UPDATERCONFIG START WITH 1 MINVALUE 1 INCREMENT BY 1
/
CREATE OR REPLACE TRIGGER GERA_ID_UPDATERCONFIG
BEFORE INSERT ON UPDATERCONFIG FOR EACH ROW
BEGIN
  SELECT SEQ_UPDATERCONFIG.NEXTVAL
    INTO :NEW.ID
    FROM DUAL;
END;
/
CREATE TABLE UPDATERCONFIGHIST
(
	ID                NUMBER 		  NOT NULL,
	UPDATERCONFIGID   NUMBER 	      NOT NULL,
	CDOPERADOR        VARCHAR2(12)    NOT NULL,
	CONFIG            VARCHAR2(4000)  NOT NULL,
	NRORG             NUMBER 	      DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg') 		NOT NULL,
    IDATIVO           VARCHAR2(1)     DEFAULT 'S'					NOT NULL,
    DTINCLUSAO        DATE            DEFAULT SYSDATE,
    DTULTATU          DATE            DEFAULT SYSDATE,
    NRORGINCLUSAO     NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERINCLUSAO    VARCHAR2(12)    DEFAULT '1' 					NULL,
    NRORGULTATU       NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERULTATU      VARCHAR2(12)    DEFAULT '1',
		CONSTRAINT CKC_IDATIVO_UPDATERCONFIGHIST CHECK (IDATIVO IN ('S','N')),
		CONSTRAINT PK_UPDATERCONFIGHIST PRIMARY KEY (ID),
		CONSTRAINT FKVND00847UPDATCONFIHSTCONFGID FOREIGN KEY (UPDATERCONFIGID) REFERENCES UPDATERCONFIG (ID),
		CONSTRAINT FKVND00848UPDATERCONFIHISTOPER FOREIGN KEY (CDOPERADOR) REFERENCES OPERADOR (CDOPERADOR)
)
/
CREATE INDEX VND00847_FK ON UPDATERCONFIGHIST  (UPDATERCONFIGID)
/
CREATE INDEX VND00848_FK ON UPDATERCONFIGHIST  (CDOPERADOR)
/
CREATE SEQUENCE SEQ_UPDATERCONFIGHIST START WITH 1 MINVALUE 1 INCREMENT BY 1
/
CREATE OR REPLACE TRIGGER GERA_ID_UPDATERCONFIGHIST
BEFORE INSERT ON UPDATERCONFIGHIST FOR EACH ROW
BEGIN
  SELECT SEQ_UPDATERCONFIGHIST.NEXTVAL
    INTO :NEW.ID
    FROM DUAL;
END;
/
CREATE TABLE UPDATERPRODCONFIG
(
	ID                NUMBER 		  NOT NULL,
	CDPRODUCTID       VARCHAR2(4)     NOT NULL,
	NRVERSAO          VARCHAR2(10)    NOT NULL,
	CONFIG            VARCHAR2(4000)  NULL,
	NRORG             NUMBER 	      DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg') 		NOT NULL,
    IDATIVO           VARCHAR2(1)     DEFAULT 'S'					NOT NULL,
    DTINCLUSAO        DATE            DEFAULT SYSDATE,
    DTULTATU          DATE            DEFAULT SYSDATE,
    NRORGINCLUSAO     NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERINCLUSAO    VARCHAR2(12)    DEFAULT '1' 					NULL,
    NRORGULTATU       NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERULTATU      VARCHAR2(12)    DEFAULT '1',
		CONSTRAINT CKC_IDATIVO_UPDATERPRODCONFIG CHECK (IDATIVO IN ('S','N')),
		CONSTRAINT PK_UPDATERPRODCONFIG PRIMARY KEY (ID)
)
/
CREATE SEQUENCE SEQ_UPDATERPRODCONFIG START WITH 1 MINVALUE 1 INCREMENT BY 1
/
CREATE OR REPLACE TRIGGER GERA_ID_UPDATERPRODCONFIG
BEFORE INSERT ON UPDATERPRODCONFIG FOR EACH ROW
BEGIN
  SELECT SEQ_UPDATERPRODCONFIG.NEXTVAL
    INTO :NEW.ID
    FROM DUAL;
END;
/
CREATE TABLE UPDATERSERVICOFILI
(
	CDFILIAL          VARCHAR2(4) 	  NOT NULL,
	MONITORAMENTO     VARCHAR2(4000)  NULL,
	NRORG             NUMBER 	      DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg') 		NOT NULL,
    IDATIVO           VARCHAR2(1)     DEFAULT 'S'					NOT NULL,
    DTINCLUSAO        DATE            DEFAULT SYSDATE,
    DTULTATU          DATE            DEFAULT SYSDATE,
    NRORGINCLUSAO     NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERINCLUSAO    VARCHAR2(12)    DEFAULT '1' 					NULL,
    NRORGULTATU       NUMBER          DEFAULT SYS_CONTEXT('nrorg_ctx','nrorg')		NULL,
    CDOPERULTATU      VARCHAR2(12)    DEFAULT '1',
		CONSTRAINT PK_UPDATERSERVICOFILI PRIMARY KEY (CDFILIAL),
		CONSTRAINT CKC_IDATIVO_UPDATERSERVICOFILI CHECK (IDATIVO IN ('S','N')),
		CONSTRAINT FKVND00849UPDATERSERVICOFILI FOREIGN KEY (CDFILIAL) REFERENCES FILIAL (CDFILIAL)
)
/
CREATE INDEX VND00849_FK ON UPDATERSERVICOFILI  (CDFILIAL)
/
INSERT INTO UPDATERSERVICOFILI (CDFILIAL)
SELECT CDFILIAL FROM FILIAL
/
COMMIT