var ZeedhiDirectives = angular.module("ZeedhiDirectives");

ZeedhiDirectives.directive('zhNewGrid', function($timeout, templateManager) {

	function calcContentWidth(element) {
		element[0]._gridColumns = [];
		element.find('.header .tr .th').each(function(colIndex, col) {
			var i, fieldName = col.getAttribute('data-zh-field-name');

			// reset previous resizing computation
			var colElements = element[0].querySelectorAll('[data-zh-field-name="' + fieldName + '"]');
			var addMarginRight = false;
			if(fieldName === '__CHECKBOX') {
				addMarginRight = !!element.find('.zh-select-multiple-order').length;
			}
			for (i = 0; i < colElements.length; i++) {
				colElements[i].style.width = 'auto';
				colElements[i].style.marginRight = (addMarginRight && i > 0) ? '12px' : 0;
			}

			if (element[0].__scope) { // element.scope()
				var widget = element[0].__scope.widget;
				var field = widget.getField(fieldName);
				var colWidth = 0;
				var fixed = (' '+col.className+' ').indexOf(' fixed ') > -1;
				var minWidth = field ? (field.minWidth || 0) : (widget.columnProperties ? (widget.columnProperties.minWidth || 0) : 0);
				var maxWidth = field ? (field.maxWidth || 99999) : (widget.columnProperties ? (widget.columnProperties.maxWidth || 99999) : 99999);
				var actionWidth = screen.width >= 1200 ? 40 : 50;
				var cellPadding = screen.width >= 1200 ? 12 : 16;

				if (fieldName == "__LEFT_ACTIONS") {
					colWidth = (element[0].__scope.visibleLeftActions * actionWidth) + cellPadding;
				} else if (fieldName == "__RIGHT_ACTIONS") {
					colWidth = (element[0].__scope.visibleRightActions * actionWidth) + cellPadding;
				} else {
					for (i = 0; i < colElements.length; i++) {
						colWidth = Math.max(colWidth, colElements[i].clientWidth);
					}

					colWidth += (fieldName === '__CHECKBOX') ? 0 : cellPadding;
				}

				if (field && !Util.isUndefined(field.inlineEditable)) {
					colWidth += 10;
				}

				if (field && field.inlineEditable === 'checkbox'){
					minWidth = maxWidth = colWidth;
				}

				element[0]._gridColumns.push({
					"name": fieldName,
					"width": colWidth,
					"_width": colWidth,
					"fixed": fixed,
					"minWidth": minWidth,
					"maxWidth": maxWidth,
					"colElements": colElements
				});
			}
		});
	}

	function adjustWidths(element) {
		var fixedWidth = 0;
		var leftActionsWidth = 0;
		var rightActionsWidth = 0;
		var dynamicCols = [];
		var dynamicWidth = 0;
		var newDynamicWidth = 0;

		var gridWidth = element.innerWidth() - 10; // space to add scrollbar
		if (element.parent().css('position') !== "absolute") {
			gridWidth += parseInt(element.parent().css('padding-left')) * 2;
		}

		element[0]._gridColumns.forEach(function(col) {
			col._minWidth = col.minWidth;
			if (col._minWidth.toString().indexOf('%') > -1) {
				col._minWidth = gridWidth * parseInt(col._minWidth)/100;
			}
			col._minWidth = parseInt(col._minWidth);

			col._maxWidth = col.maxWidth;
			if (col._maxWidth.toString().indexOf('%') > -1) {
				col._maxWidth = gridWidth * parseInt(col._maxWidth)/100;
			}
			col._maxWidth = Math.max(parseInt(col._maxWidth), col._minWidth);

			col._width = Math.min(Math.max(col.width, col._minWidth), col._maxWidth);

			if (col.name == '__LEFT_ACTIONS') {
				if (Util.isPhone()) {
					leftActionsWidth += col.width;
				} else {
					fixedWidth += col.width;
				}
			} else if (col.name == '__RIGHT_ACTIONS') {
				rightActionsWidth += col.width;
			} else if (col.fixed) {
				fixedWidth += col._width;
			} else {
				dynamicWidth += col._width;
				dynamicCols.push(col);
			}
		});

		var rightActionsMarginRight = rightActionsWidth > 0 ? 10 : 0;
		var verticalScrollWidth = 11;
		var columnsWidth = fixedWidth + leftActionsWidth + rightActionsWidth + dynamicWidth;
		if (columnsWidth < gridWidth && dynamicCols.length > 0) {
			var maxWidthAdjust = 0;
			dynamicCols.forEach(function(col, idx) {
				var newWidth = col._width * (gridWidth - fixedWidth - leftActionsWidth - rightActionsWidth - verticalScrollWidth - rightActionsMarginRight) / dynamicWidth;
				if (maxWidthAdjust > 0) {
					newWidth += maxWidthAdjust;
				}
				if (newWidth > col._maxWidth) {
					maxWidthAdjust += (newWidth - col._maxWidth) / (dynamicCols.length - idx - 1);
					col._width = col._maxWidth;
				} else {
					col._width = newWidth;
				}
				newDynamicWidth += col._width;
			});
		} else {
			newDynamicWidth = dynamicWidth;
		}

		var rightActionsMarginLeft = gridWidth - (fixedWidth + leftActionsWidth + rightActionsWidth + newDynamicWidth + verticalScrollWidth + 10);
		var rightGridActions = element.find('.right-grid-actions');
		rightGridActions.css('margin-right', rightActionsMarginRight);
		if (rightActionsMarginLeft > 0) {
			rightGridActions.css('margin-left', rightActionsMarginLeft);
		}

		var scrollControl = element.find('.body-scroll-control');
		var gridId = element.attr('id');
		scrollControl.css('left', fixedWidth);
		scrollControl.find('div').css('width', newDynamicWidth + leftActionsWidth + rightActionsWidth);
		scrollControl.trigger('scroll.' + gridId);

		if (Util.isUndefined(element[0]._gridScrollEvents) && element[0].__scope) {
			var body = element.find('.body');

			scrollControl.on('scroll.' + gridId, function(e) {
				var left = $(e.target).scrollLeft();
				element.find('.tr').each(function(index, tr) {
					if (index === 0) {
						$(tr).find('.th:not(.fixed)').eq(0).css('margin-left', -left);
					} else {
						$(tr).find('.td.zh-standard-column:not(.fixed)').eq(0).css('margin-left', -left);
					}
				});
			});

			body.on('DOMMouseScroll.' + gridId + ' mousewheel.' + gridId, function(e) {
				var deltaX = e.originalEvent.wheelDeltaX;
				if (deltaX !== 0) {
					scrollControl[0].scrollLeft -= deltaX;
					e.preventDefault();
				}
			});

			body.on('touchstart.' + gridId, function(e) {
				element[0]._touchstartX = e.originalEvent.touches[0].pageX;
				element[0]._touchstartY = e.originalEvent.touches[0].pageY;
			});

			body.on('touchmove.' + gridId, function(e) {
				var deltaX = e.originalEvent.touches[0].pageX - element[0]._touchstartX;
				if (deltaX !== 0) {
					element[0]._touchstartX = e.originalEvent.touches[0].pageX;
					scrollControl[0].scrollLeft -= deltaX;
				}

				var deltaY = e.originalEvent.touches[0].pageY - element[0]._touchstartY;
				if (deltaY !== 0) {
					element[0]._touchstartY = e.originalEvent.touches[0].pageY;
					var topScrollElement = element.find('.grid-vertical-scroll-control')[0];
					if(topScrollElement){
						topScrollElement.scrollTop -= deltaY;
					}
					if (element[0].__scope.widget._calcTopRow) {
						element[0].__scope.widget._calcTopRow();
					}
				}
			});

			element[0].__scope.$on('$destroy', function() {
				scrollControl.off('scroll.' + gridId);
				body.off('DOMMouseScroll.' + gridId + ' mousewheel.' + gridId);
				body.off('touchstart.' + gridId);
				body.off('touchmove.' + gridId);
			});

			element[0]._gridScrollEvents = true;
		}
	}

	function resizeColumns(element) {
		element[0]._gridColumns.forEach(function(col) {
			for (var i = 0; i < col.colElements.length; i++) {
				col.colElements[i].style.width = col._width+'px';
			}
		});
	}

	function resizeGrid(element, forceRecalc) {
		if ((element[0].__scope && element[0].__scope.widget && element[0].__scope.widget._gridResize) || forceRecalc) {
			element[0]._gridColumns = undefined;
		}
		if (Util.isUndefined(element[0]._gridColumns)) {
			if (element[0].__scope && element[0].__scope.widget) element[0].__scope.widget._gridResize = false;
			calcContentWidth(element);
			adjustWidths(element);
		}
		resizeColumns(element);
		showData(element,forceRecalc);
	}

	function animateRedrawing(element) {
		hideData(element);
	}

	function hideData(element) {
		element.find('.th, .tr').css('opacity', 0);
	}

	function showData(element, animate) {
		if (animate) {
			element.find('.th, .tr').animate({
				'opacity': 1
			}, 300);
		} else {
			element.find('.th, .tr').css('opacity', 1);
		}
	}

	$(window).on('resize.grid', function(event, element) {
		var grids;
		if (Util.isUndefined(element)) {
			grids = $('.zh-new-grid');
		} else if (Util.isString(element)) {
			grids = $('#grid-' + element);
		} else {
			grids = $(element).find('.zh-new-grid');
		}
		grids.each(function(index, grid) {
			$timeout(function() {
				resizeGrid($(grid), true);
				$(window).trigger('resize.grid.after');
			}, 300, false);
		});
	});

	return {
		link: function($scope, element, attrs, controller) {
			var widget = $scope.widget;
			element[0].__scope = $scope;

			$scope.$on('$destroy', function() {
				delete element[0].__scope;
				delete widget.resizeGridColumns;
				delete widget.redraw;
				delete widget._getVisibilityParams;
				delete widget._calcScrollAreas;
				delete widget._calcTopRow;
			});

			widget.focusElement = function() {
				element.focus();
			};
			
			var _resizeGrid = Util.buildDebounceMethod(function(forceRecalc) {
				$timeout(function() {
					resizeGrid(element, forceRecalc);
					if (widget.focusable && widget.autoFocus) widget.focusElement();
				}, 100, false);
			}, 300);

			$scope.resizeGridColumns = function(forceRecalc) {
				_resizeGrid(forceRecalc);
			};
			widget.resizeGridColumns = $scope.resizeGridColumns;

			function gridRedraw(force) {
				animateRedrawing(element);
				widget.updateGroups();
				widget.updateFilteredFields();
				widget.resizeGridColumns(force);
			}

			widget.redraw = gridRedraw;

			if (widget.onRender) {
				widget.onRender(function() {
					$scope.buildGridActions();
					widget.reload();
					$scope.resizeGridColumns(true);
				});
			}

			widget._getVisibilityParams = function() {
				var rowHeight = screen.width > 1200 ? 36 : 47;
				var gridBodyArea = element.find('.body').outerHeight();
				// To fix the behavior of body height being 0 even if the body visually have a height, a fallback will be used
				if (!gridBodyArea && element.is(':visible')) {
					var headerHeight = element.find('.header').height();
					var bodyScrollControlHeight = element.find('.body-scroll-control').height();
					gridBodyArea = element.height() - headerHeight - bodyScrollControlHeight;
					if (gridBodyArea <= 0) {
						gridBodyArea = 0;
					}
				}

				widget._visibilityParams = {
					rowHeight: rowHeight,
					maxVisibleRows: Math.max(1, Math.floor(gridBodyArea / rowHeight))
				};
			};

			widget._calcScrollAreas = function _calcScrollAreas() {
				var totalHeight = 0;
				var body = element.find('.body');
				var visibilityParams = widget._visibilityParams;
				// var heightAdjust = body.outerHeight() - (visibilityParams ? visibilityParams.rowHeight * visibilityParams.maxVisibleRows : 0);

				if (widget._hiddenRows > 0) {
					totalHeight = (widget._hiddenRows * (visibilityParams ? visibilityParams.rowHeight : 0));
				}

				var scrollControl = element.find('.grid-vertical-scroll-control');
				scrollControl.find('div').height(totalHeight + scrollControl.height());
			};

			widget._calcTopRow = function _calcTopRow() {
				if ($(':focus').is('.inline-edit')) {
					$(':focus').blur();
				}

				var body = element.find('.body');
				var scrollControl = element.find('.grid-vertical-scroll-control');
				var visibilityParams = widget._visibilityParams;
				widget._topRow = Math.round(scrollControl.scrollTop() / (visibilityParams ? visibilityParams.rowHeight : 0));
				widget._updateVisibleRows();
				if (!Util.isMobile()) {
					widget._calcScrollAreas();
				}

				if (scrollControl[0] && (scrollControl[0].scrollTop + scrollControl[0].offsetHeight) >= (scrollControl[0].scrollHeight - (visibilityParams.rowHeight * 3))) {
					body.find('.body-content').trigger('scroll.infinity', widget.hasPagination && !widget.dataSource.loadedAllData);
				}

				templateManager.updateTemplate();
			};

			var _debounceCalcTopRow = Util.buildDebounceMethod(widget._calcTopRow, 200);
			var _throttleCalcTopRow = Util.buildThrottleMethod(widget._calcTopRow, 10, widget);

			if (!Util.isMobile()) {
				element.find('.grid-vertical-scroll-control').on('scroll', _throttleCalcTopRow);
			} else {
				element.find('.grid-vertical-scroll-control').on('scroll', _debounceCalcTopRow);
			}

			element.find('.body-content').on('mousewheel wheel DOMMouseScroll', function(e) {
				element.find('.grid-vertical-scroll-control')[0].scrollTop += e.originalEvent.deltaY;
			});
			
			element.on('keydown.new-grid', function(event) {
				var focused_row = element.find('.body .tr.focus');
				var scrollControl = element.find('.grid-vertical-scroll-control')[0];

				// Space ou Enter
				if (event.keyCode === 32 || (event.keyCode === 13 && !event.ctrlKey && !event.metaKey)) {
					if (widget.showCheckbox) {
						if (event.ctrlKey || event.metaKey) {
							$scope.controller.toggleAll();
							templateManager.updateTemplate();
						} else {
							if (focused_row.length) {
								var checkbox = focused_row.eq(0).find('.grid-checkbox-column');
								checkbox.trigger('click');
							}
						}
					}
					// Down
				} else if (event.keyCode == 40) {
					if (focused_row.length === 0) {
						focused_row = element.find('.body .tr').eq(0);
						focused_row.addClass('focus');
					} else {
						if (focused_row.next().length > 0) {
							focused_row.removeClass('focus');
							var next = focused_row.next();
							next.addClass('focus');
						} else {
							if (scrollControl.scrollTop + scrollControl.clientHeight < scrollControl.scrollHeight) {
								scrollControl.scrollTop = Math.min(scrollControl.scrollHeight - scrollControl.clientHeight, scrollControl.scrollTop + focused_row.height());
							} 
						}
					}
					// Up
				} else if (event.keyCode == 38) {
					if (focused_row.length === 0) {
						focused_row = element.find('.body .tr').last();
						focused_row.addClass('focus');
					} else {
						if (focused_row.prev().length > 0) {
							focused_row.removeClass('focus');
							var prev = focused_row.prev();
							prev.addClass('focus');
						} else {
							if (scrollControl.scrollTop > 0) {
								scrollControl.scrollTop = Math.max(0, scrollControl.scrollTop - focused_row.height());
							} 
						}
					}
				}
			});
			
			widget.selectRow = function(index) {
				var rows = element.find('.body .tr');
				rows.removeClass('focus');
				rows.eq(index).addClass('focus');
			};
		}
	};
});