package com.javaseleniumtemplate.tests;

import com.javaseleniumtemplate.bases.TestBase;
import com.javaseleniumtemplate.flows.LoginFlows;
import com.javaseleniumtemplate.flows.PratoFlows;
import com.javaseleniumtemplate.pages.PratoPage;
import org.testng.annotations.Test;

public class PratoTests extends TestBase {

    PratoPage pratoPage;
    PratoFlows pratoFlows;
    LoginFlows loginFlows;

    //Tentar salvar um produto de produção, nos dados da receita padrão. Como este produto já está sendo usado, deve emitir uma mensagem informando isso.
    //No fim do teste será verificado se a mensagem exbida é a esperada
    @Test
    public void produtoProducaoSendoUsadoReceitaPadrao() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Padrão");
        pratoPage.produtoProducaoRepetido("Padrão");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //deixar os campos de aproveitamento da cocção e limpeza da receita padrão vazios e verificar qual a mensagem é exbida na tela
    @Test
    public void aproveitamentoCoccaoLimpezaVaziosPadrao() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Padrão");
        pratoPage.aproveitamentoCoccaoELimpezaVazios("Padrão");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //adicionar o produto carum na receita padrão, verificar os dados do produto adicionado e excluir o mesmo
    @Test
    public void adicionarProdutoReceitaPadrao() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Padrão");
        pratoPage.adicionarCarumPadrao();
        pratoPage.verificarCarumPadrao();
        pratoPage.excluirProdutoCarum("Padrão");


        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //tentar adicionar o produto carum nos produtos da receita padrão, com os campos vazios, fazer a verificação dos campos obrigatórios
    //na próxima tentativa, adicionar com dados. Na aba dados da receita, testar o botão "calcular", editar os campos dos dados da receita,
    //realizar a verificação dos dados alterados, desfazer todas as edições, para que nos próximos testes, os valores sejam alterados
    //e por fim excluir o produto carum
    @Test
    public void adiconarProdutoPadraoCampoVazios() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Padrão");
        pratoPage.adicionarCarumPadraoCamposVazios();
        pratoPage.editarProdutoCarumPadrao();
        pratoPage.calcularQuantidadePessoaPadrao();
        pratoPage.editarDadosReceitaPadrao();
        pratoPage.verificarEdicaoDadosReceitaPadrao();
        pratoPage.desfazerEdicaoDadosReceitaPadrao();
        pratoPage.excluirProdutoCarum("Padrão");


        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //adicionar um modo de praparo, editar e excluir o mesmo
    @Test
    public void modoPreparoReceitaPadrao() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecModoPreparo("Padrão");
        pratoPage.adicionarModoPreparoPadrao();
        pratoPage.editarModoPreparoPadrao();
        pratoPage.excluirModoPreparo("Padrão");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //verificar quais colunas serão apresentadas com os dados dos nutrientes, na ação 'consultar nutrientes' da receita padrão
    @Test
    public void consultarNutrientesReceitaPadrao() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Padrão");
        pratoPage.consultarNutrienteReceita();

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //Tentar salvar um produto de produção, nos dados da receita local. Como este produto já está sendo usado, deve emitir uma mensagem informando isso.
    // No fim do teste será verificado se a mensagem exbida é a esperada
    @Test
    public void produtoProducaoSendoUsadoReceitaLocal() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Local");
        pratoPage.produtoProducaoRepetido("Local");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //deixar os campos de aproveitamento da cocção e limpeza da receita local vazios e verificar qual a mensagem é exbida na tela
    @Test
    public void aproveitamentoCoccaoLimpezaVaziosLocal() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Local");
        pratoPage.aproveitamentoCoccaoELimpezaVazios("Local");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //adicionar o produto carum na receita local, verificar os dados do produto adicionado e excluir o mesmo
    @Test
    public void adicionarProdutoReceitaLocal() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Local");
        pratoPage.adicionarCarumLocal();
        pratoPage.verificarCarumLocal();
        pratoPage.excluirProdutoCarum("Local");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //tentar adicionar o produto carum nos produtos da receita local, com os campos vazios, fazer a verificação dos campos obrigatórios
    //na próxima tentativa, adicionar com dados. Na aba dados da receita, testar o botão "calcular", editar os campos dos dados da receita,
    //realizar a verificação dos dados alterados, desfazer todas as edições, para que nos próximos testes, os valores sejam alterados
    //e por fim excluir o produto carum
    @Test
    public void adiconarProdutoLocalCampoVazios() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Local");
        pratoPage.adicionarCarumLocalCamposVazios();
        pratoPage.editarProdutoCarumLocal();
        pratoPage.calcularQuantidadePessoaLocal();
        pratoPage.editarDadosReceitaLocal();
        pratoPage.verificarEdicaoDadosReceitaLocal();
        pratoPage.desfazerEdicaoDadosReceitaLocal();
        pratoPage.excluirProdutoCarum("Local");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //adicionar um modo de praparo, editar e excluir o mesmo
    @Test
    public void modoPreparoReceitaLocal() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecModoPreparo("Local");
        pratoPage.adicionarModoPreparoLocal();
        pratoPage.editarModoPreparoLocal();
        pratoPage.excluirModoPreparo("Local");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //verificar quais colunas serão apresentadas com os dados dos nutrientes, na ação 'consultar nutrientes' da receita local
    @Test
    public void consultarNutrientesReceitaLocal() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Local");
        pratoPage.adicionarCarumLocal();
        pratoPage.consultarNutrienteReceita();
        pratoPage.excluirProdutoCarum("Local");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //Tentar salvar um produto de produção, nos dados da receita serviço. Como este produto já está sendo usado, deve emitir uma mensagem informando isso.
    //No fim do testeb será verificado se a mensagem exbida é a esperada
    @Test
    public void produtoProducaoSendoUsadoReceitaServico() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Serviço");
        pratoPage.produtoProducaoRepetido("Serviço");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //deixar os campos de aproveitamento da cocção e limpeza da receita serviço vazios e verificar qual a mensagem é exbida na tela
    @Test
    public void aproveitamentoCoccaoLimpezaVaziosServico() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Serviço");
        pratoPage.aproveitamentoCoccaoELimpezaVazios("Serviço");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //adicionar o produto carum na receita serviço, verificar os dados do produto adicionado e excluir o mesmo
    @Test
    public void adicionarProdutoReceitaServico() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Serviço");
        pratoPage.adicionarCarumServico();
        pratoPage.verificarCarumServico();
        pratoPage.excluirProdutoCarum("Serviço");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //tentar adicionar o produto carum nos produtos da receita serviço, com os campos vazios, fazer a verificação dos campos obrigatórios
    //na próxima tentativa, adicionar com dados. Na aba dados da receita, testar o botão "calcular", editar os campos dos dados da receita,
    //realizar a verificação dos dados alterados, desfazer todas as edições, para que nos próximos testes, os valores sejam alterados
    //e por fim excluir o produto carum
    @Test
    public void adicionarProdutoServicoCamposVazios() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Serviço");
        pratoPage.adicionarCarumServicoCamposVazios();
        pratoPage.editarProdutoCarumServico();
        pratoPage.calcularQuantidadePessoaServico();
        pratoPage.editarDadosReceitaServico();
        pratoPage.verificarEdicaoDadosReceitaServico();
        pratoPage.desfazerEdicaoDadosReceitaServico();
        pratoPage.excluirProdutoCarum("Serviço");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //adicionar um modo de preparo, editar e excluir o mesmo
    @Test
    public void modoPreparoReceitaServico() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecModoPreparo("Serviço");
        pratoPage.adicionarModoPreparoServico();
        pratoPage.editarModoPreparoServico();
        pratoPage.excluirModoPreparo("Serviço");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //verificar quais colunas serão apresentadas com os dados dos nutrientes, na ação 'consultar nutrientes' da receita serviço
    @Test
    public void consultarNutrientesReceitaServico() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Serviço");
        pratoPage.adicionarCarumServico();
        pratoPage.consultarNutrienteReceita();
        pratoPage.excluirProdutoCarum("Serviço");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //adicionar o produto carum na receita padrão de qualidade, verificar os dados do produto adicionado e excluir o mesmo
    @Test
    public void adicionarProdutoReceitaPadraoQualidade() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Padrão de Qualidade");
        pratoPage.adicionarCarumPadraoQualidade();
        pratoPage.verificarCarumPadraoQualidade();
        pratoPage.excluirProdutoCarum("Padrão de Qualidade");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //deixar os campos de aproveitamento da cocção e limpeza da receita padrão de qualidade vazios e verificar qual a mensagem é exbida na tela
    @Test
    public void aproveitamentoCoccaoLimpezaVaziosPadraoQualidade() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Padrão de Qualidade");
        pratoPage.aproveitamentoCoccaoELimpezaVazios("Padrão de Qualidade");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //tentar adicionar o produto carum nos produtos da receita padrão de qualidade, com os campos vazios, fazer a verificação dos campos obrigatórios
    //na próxima tentativa, adicionar com dados. Na aba dados da receita, testar o botão "calcular", editar os campos dos dados da receita,
    //realizar a verificação dos dados alterados, desfazer todas as edições, para que nos próximos testes, os valores sejam alterados
    //e por fim excluir o produto carum
    @Test
    public void adiconarProdutoPadraoQualidadeCampoVazios() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Padrão de Qualidade");
        pratoPage.adicionarCarumPadraoQualidadeCamposVazios();
        pratoPage.editarProdutoCarumPadraoQualidade();
        pratoPage.calcularQuantidadePessoaPadraoQualidade();
        pratoPage.editarDadosReceitaPadraoQualidade();
        pratoPage.verificarEdicaoDadosReceitaPadraoQualidade();
        pratoPage.desfazerEdicaoDadosReceitaPadraoQualidade();
        pratoPage.excluirProdutoCarum("Padrão de Qualidade");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //adicionar um modo de preparo, editar e excluir o mesmo
    @Test
    public void modoPreparoReceitaPadraoQualidade() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecModoPreparo("Padrão de Qualidade");
        pratoPage.adicionarModoPreparoPadraoQualidade();
        pratoPage.editarModoPreparoPadraoQualidade();
        pratoPage.excluirModoPreparo("Padrão de Qualidade");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //adicionar o produto carum na receita região, verificar os dados do produto adicionado e excluir o mesmo
    @Test
    public void adicionarProdutoReceitaRegiao() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Região");
        pratoPage.adicionarCarumRegiao();
        pratoPage.verificarCarumRegiao();
        pratoPage.excluirProdutoCarum("Região");


        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //deixar os campos de aproveitamento da cocção e limpeza da receita região vazios e verificar qual a mensagem é exbida na tela
    @Test
    public void aproveitamentoCoccaoLimpezaVaziosRegiao() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Região");
        pratoPage.aproveitamentoCoccaoELimpezaVazios("Região");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //tentar adicionar o produto carum nos produtos da receita padrão de qualidade, com os campos vazios, fazer a verificação dos campos obrigatórios
    //na próxima tentativa, adicionar com dados. Na aba dados da receita, testar o botão "calcular", editar os campos dos dados da receita,
    //realizar a verificação dos dados alterados, desfazer todas as edições, para que nos próximos testes, os valores sejam alterados
    //e por fim excluir o produto carum
    @Test
    public void adiconarProdutoRegiaoCampoVazios() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecReceita("Região");
        pratoPage.adicionarCarumRegiaoCamposVazios();
        pratoPage.editarProdutoCarumRegiao();
        pratoPage.calcularQuantidadePessoaRegiao();
        pratoPage.editarDadosReceitaRegiao();
        pratoPage.verificarEdicaoDadosReceitaRegiao();
        pratoPage.desfazerEdicaoDadosReceitaRegiao();
        pratoPage.excluirProdutoCarum("Região");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //adicionar um modo de preparo, editar e excluir o mesmo
    @Test
    public void modoPreparoReceitaRegiao() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.selecModoPreparo("Região");
        pratoPage.adicionarModoPreparoRegiao();
        pratoPage.editarModoPreparoRegiao();
        pratoPage.excluirModoPreparo("Região");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //adicionar, editar e excluir embalagem do prato
    @Test
    public void embalagemPrato() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.adicionarEmbalagem();
        pratoPage.editarEmbalagem();
        pratoPage.excluirEmbalagem();


        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //tentar adicionar uma embalagem com os campos container e quantidade vazios, para verificar se os mesmos são obrigatórios
    @Test
    public void campoObrigatorioEmbalagemPrato() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.abrirArvoreSelecFeijoadaMagra();
        pratoPage.verificarCampoObrigatorioEmbalagem();

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //alterar a finalização para 'unidade' e 'matriz' em uma receita que possui 'produto de produção' igual ao de outra receita
    //a alteração é realizada em receitas dos tipos: padrão, local e serviço, do prato salada de alface
    @Test
    public void alterarFinalizacao() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.acessarPratoSaladaAlface();
        pratoPage.selecReceita("Padrão");
        pratoPage.alterarFinalizacao("Padrão");
        pratoPage.selecReceita("Local");
        pratoPage.alterarFinalizacao("Local");
        pratoPage.selecReceita("Serviço");
        pratoPage.alterarFinalizacao("Serviço");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //tentar adicionar e excluir um produto de uma receita que possui um produto de produção que também é usado em outra receita
    @Test
    public void tentaAlterarRecComProdPadrRepetido() {
        pratoPage = new PratoPage();
        pratoFlows = new PratoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        pratoFlows.navegateTelaPrato();
        pratoPage.acessarPratoSaladaAlface();
        pratoPage.selecReceita("Padrão");
        pratoPage.tentarAlterarRecComProdPadrRepetido();
        pratoPage.selecReceita("Local");
        pratoPage.tentarAlterarRecComProdPadrRepetido();
        pratoPage.selecReceita("Serviço");
        pratoPage.tentarAlterarRecComProdPadrRepetido();

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }
}